# pyqt-fitting-graphics-view
PyQt QGraphicsView which always fit the aspect ratio mode as `Qt.KeepAspectRatio`

## Requirements
* PyQt5 >= 5.8

## Setup
`python -m pip install pyqt-fitting-graphics-view`

## Included Package
* <a href="https://github.com/yjg30737/pyqt-single-image-graphics-view.git">pyqt-single-image-graphics-view</a> - For inheriting class ```SingleImageGraphicsView```
